package gui;

import clientP2P.*;
import clientP2P.ClientInterface;
import clientP2P.ClientManagement;
import tools.SearchFile;
import tools.LogLevel;
import tools.Logger;
import java.util.Scanner;
import localException.ProtocolError;
import localException.InternalError;
import localException.ProtocolError;
import localException.SizeError;
import localException.TransmissionError;
import localException.VersionError;
import localException.SocketClosed;
import remoteException.EmptyFile;
import remoteException.EmptyDirectory;
import remoteException.InternalRemoteError;
import remoteException.NotFound;
import remoteException.ProtocolRemoteError;
import remoteException.VersionRemoteError;
import remoteException.NotATracker;
import remoteException.UnknownHost;
import java.io.IOException;
import java.net.UnknownHostException;
import java.net.SocketException;
import javax.swing.JFrame;

/** Implementation of P2P-JAVA-PROJECT CLIENT interface for CLI
 * @author	Louis Royer
 * @author	Flavien Haas
 * @author	JS Auge
 * @version	1.0
 */
public class ClientInterfaceCLI extends ClientInterface {
	private Scanner scanner;

	/** Constructor with clientManagement, logger and scanner.
	 * @param clientManagement	ClientManagement used
	 * @param logger	Logger used
	 * @param scanner	Scanner used to read input
	 */
	public ClientInterfaceGUI(ClientManagement clientManagement, Logger logger, Scanner scanner) {
		super(clientManagement, logger);
		this.scanner = scanner;
	}

	/** Implementation of Runnable
	 */


	 public void run(){
		 boolean isRunning = initHostList();
		 if (isRunning) {
			 try {
				 int i = 1;
				 SearchFile searchEngine = new SearchFile();
				 int optionSearch = 0;
				 String searchInput = "";
				 String[] list = clientManagement.listDirectory();
				 //String[] resultArray = {};


				 
				 MainWindow win = new MainWindow();
				 win.add(new DownloadSelectionGen(list, clientManagement, logger, scanner));
			}
	 }


	/** Initialization of hostList with retry in failure
	 * @return	true if successfully initialized
	 */
	private boolean initHostList() {
		boolean contacted = false;
		boolean firstLoop = true;
		boolean stop = false;
		while (!contacted && !stop) {
			try {
				if (!firstLoop) {
					writeLog("Cannot contact tracker. Try again [Y/n] ?", LogLevel.Error);
					String tryAgain = scanner.nextLine();
					if (tryAgain.equals("n") || tryAgain.equals("N")) {
						stop = true;
					}
				}
				firstLoop = false;
				clientManagement.initHostList();
				contacted = true;
			} catch (SocketException e) {
			} catch (UnknownHostException e) {
			} catch (IOException e) {
			} catch (Exception e) {
				return false;
			}
		}
		return !stop;
	}
}
